@@ -20,11 +20,11 @@ class JetStreamMessagingBot(BaseModel):
     class Config:
         arbitrary_types_allowed = True
 
-    async def connect(self):
+    async def connect(self, timeout: int = 10):
         try:
             self.nc = await nats.connect(servers=[self.nats_url])
             logging.info(f"NATS: Connected")
-            self.js = self.nc.jetstream()
+            self.js = self.nc.jetstream(timeout=timeout)
             logging.info(f"NATS: JetStream {self.botname} Created")
         except TimeoutError as err:
             logging.debug(err)
